==> kdenetwork-3.3.2.tar.bz2: kdenetwork-3.3.2/kopete/libkopete/kopetenotifyevent.h <==
/*
    kopetenotifyevent.h - Container for presentations of an event

    Copyright (c) 2004 by Will Stephenson     <lists@stevello.free-online.co.uk>

    Kopete    (c) 2002-2004 by the Kopete developers  <kopete-devel@kde.org>

    *************************************************************************
    *                                                                       *
    * This library is free software; you can redistribute it and/or         *
    * modify it under the terms of the GNU Lesser General Public            *
    * License as published by the Free Software Foundation; either          *
    * version 2 of the License, or (at your option) any later version.      *
    *                                                                       *
    *************************************************************************
*/

#ifndef KOPETENOTIFYEVENT_H
#define KOPETENOTIFYEVENT_H

#include <qstring.h>
#include <qvaluelist.h>
#include "kopeteeventpresentation.h"

class QDomElement;

class KopeteNotifyEvent
{
public:
	KopeteNotifyEvent( const bool suppressCommon = false );
	~KopeteNotifyEvent();

	bool suppressCommon() const;
	KopeteEventPresentation *presentation( const KopeteEventPresentation::PresentationType type ) const;
	void setPresentation( const KopeteEventPresentation::PresentationType type, KopeteEventPresentation * );
	void removePresentation( const KopeteEventPresentation::PresentationType type );
	/**
	 * @return true if the presentation was single shot 
	 */
	bool firePresentation( const KopeteEventPresentation::PresentationType type );
	
	void setSuppressCommon( bool suppress );
	const QValueList<QDomElement> toXML() const;
	QString toString();
private:
	QString m_event;
	KopeteEventPresentation *m_sound;
	KopeteEventPresentation *m_message;
	KopeteEventPresentation *m_chat;
	bool m_suppressCommon;
};

#endif

==> kdenetwork-3.5.10.tar.bz2: kdenetwork-3.5.10/kopete/libkopete/kopetenotifyevent.h <==
/*
    kopetenotifyevent.h - Container for presentations of an event

    Copyright (c) 2004 by Will Stephenson     <lists@stevello.free-online.co.uk>

    Kopete    (c) 2002-2004 by the Kopete developers  <kopete-devel@kde.org>

    *************************************************************************
    *                                                                       *
    * This library is free software; you can redistribute it and/or         *
    * modify it under the terms of the GNU Lesser General Public            *
    * License as published by the Free Software Foundation; either          *
    * version 2 of the License, or (at your option) any later version.      *
    *                                                                       *
    *************************************************************************
*/

#ifndef KOPETENOTIFYEVENT_H
#define KOPETENOTIFYEVENT_H

#include <qstring.h>
#include <qvaluelist.h>
#include "kopeteeventpresentation.h"

#include "kopete_export.h"

class QDomElement;

namespace Kopete
{

class KOPETE_EXPORT NotifyEvent
{
public:
	NotifyEvent( const bool suppressCommon = false );
	~NotifyEvent();

	bool suppressCommon() const;
	EventPresentation *presentation( const EventPresentation::PresentationType type ) const;
	void setPresentation( const EventPresentation::PresentationType type, EventPresentation * );
	void removePresentation( const EventPresentation::PresentationType type );
	/**
	 * @return true if the presentation was single shot 
	 */
	bool firePresentation( const EventPresentation::PresentationType type );
	
	void setSuppressCommon( bool suppress );
	const QValueList<QDomElement> toXML() const;
	QString toString();
private:
	QString m_event;
	EventPresentation *m_sound;
	EventPresentation *m_message;
	EventPresentation *m_chat;
	bool m_suppressCommon;
};

}

#endif
